#line 2 "lib/cfg-lex.c"

#line 4 "lib/cfg-lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define _cfg_lexer__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer _cfg_lexer__create_buffer
#endif

#ifdef yy_delete_buffer
#define _cfg_lexer__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer _cfg_lexer__delete_buffer
#endif

#ifdef yy_scan_buffer
#define _cfg_lexer__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer _cfg_lexer__scan_buffer
#endif

#ifdef yy_scan_string
#define _cfg_lexer__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string _cfg_lexer__scan_string
#endif

#ifdef yy_scan_bytes
#define _cfg_lexer__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes _cfg_lexer__scan_bytes
#endif

#ifdef yy_init_buffer
#define _cfg_lexer__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer _cfg_lexer__init_buffer
#endif

#ifdef yy_flush_buffer
#define _cfg_lexer__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer _cfg_lexer__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define _cfg_lexer__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state _cfg_lexer__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define _cfg_lexer__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer _cfg_lexer__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define _cfg_lexer_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state _cfg_lexer_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define _cfg_lexer_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state _cfg_lexer_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define _cfg_lexer_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack _cfg_lexer_ensure_buffer_stack
#endif

#ifdef yylex
#define _cfg_lexer_lex_ALREADY_DEFINED
#else
#define yylex _cfg_lexer_lex
#endif

#ifdef yyrestart
#define _cfg_lexer_restart_ALREADY_DEFINED
#else
#define yyrestart _cfg_lexer_restart
#endif

#ifdef yylex_init
#define _cfg_lexer_lex_init_ALREADY_DEFINED
#else
#define yylex_init _cfg_lexer_lex_init
#endif

#ifdef yylex_init_extra
#define _cfg_lexer_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra _cfg_lexer_lex_init_extra
#endif

#ifdef yylex_destroy
#define _cfg_lexer_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy _cfg_lexer_lex_destroy
#endif

#ifdef yyget_debug
#define _cfg_lexer_get_debug_ALREADY_DEFINED
#else
#define yyget_debug _cfg_lexer_get_debug
#endif

#ifdef yyset_debug
#define _cfg_lexer_set_debug_ALREADY_DEFINED
#else
#define yyset_debug _cfg_lexer_set_debug
#endif

#ifdef yyget_extra
#define _cfg_lexer_get_extra_ALREADY_DEFINED
#else
#define yyget_extra _cfg_lexer_get_extra
#endif

#ifdef yyset_extra
#define _cfg_lexer_set_extra_ALREADY_DEFINED
#else
#define yyset_extra _cfg_lexer_set_extra
#endif

#ifdef yyget_in
#define _cfg_lexer_get_in_ALREADY_DEFINED
#else
#define yyget_in _cfg_lexer_get_in
#endif

#ifdef yyset_in
#define _cfg_lexer_set_in_ALREADY_DEFINED
#else
#define yyset_in _cfg_lexer_set_in
#endif

#ifdef yyget_out
#define _cfg_lexer_get_out_ALREADY_DEFINED
#else
#define yyget_out _cfg_lexer_get_out
#endif

#ifdef yyset_out
#define _cfg_lexer_set_out_ALREADY_DEFINED
#else
#define yyset_out _cfg_lexer_set_out
#endif

#ifdef yyget_leng
#define _cfg_lexer_get_leng_ALREADY_DEFINED
#else
#define yyget_leng _cfg_lexer_get_leng
#endif

#ifdef yyget_text
#define _cfg_lexer_get_text_ALREADY_DEFINED
#else
#define yyget_text _cfg_lexer_get_text
#endif

#ifdef yyget_lineno
#define _cfg_lexer_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno _cfg_lexer_get_lineno
#endif

#ifdef yyset_lineno
#define _cfg_lexer_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno _cfg_lexer_set_lineno
#endif

#ifdef yyget_column
#define _cfg_lexer_get_column_ALREADY_DEFINED
#else
#define yyget_column _cfg_lexer_get_column
#endif

#ifdef yyset_column
#define _cfg_lexer_set_column_ALREADY_DEFINED
#else
#define yyset_column _cfg_lexer_set_column
#endif

#ifdef yywrap
#define _cfg_lexer_wrap_ALREADY_DEFINED
#else
#define yywrap _cfg_lexer_wrap
#endif

#ifdef yyget_lval
#define _cfg_lexer_get_lval_ALREADY_DEFINED
#else
#define yyget_lval _cfg_lexer_get_lval
#endif

#ifdef yyset_lval
#define _cfg_lexer_set_lval_ALREADY_DEFINED
#else
#define yyset_lval _cfg_lexer_set_lval
#endif

#ifdef yyget_lloc
#define _cfg_lexer_get_lloc_ALREADY_DEFINED
#else
#define yyget_lloc _cfg_lexer_get_lloc
#endif

#ifdef yyset_lloc
#define _cfg_lexer_set_lloc_ALREADY_DEFINED
#else
#define yyset_lloc _cfg_lexer_set_lloc
#endif

#ifdef yyalloc
#define _cfg_lexer_alloc_ALREADY_DEFINED
#else
#define yyalloc _cfg_lexer_alloc
#endif

#ifdef yyrealloc
#define _cfg_lexer_realloc_ALREADY_DEFINED
#else
#define yyrealloc _cfg_lexer_realloc
#endif

#ifdef yyfree
#define _cfg_lexer_free_ALREADY_DEFINED
#else
#define yyfree _cfg_lexer_free
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define _cfg_lexer_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 78
#define YY_END_OF_BUFFER 79
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[256] =
    {   0,
       79,   24,   31,   78,    5,   31,   78,    4,   78,   31,
       78,   24,   31,   78,   28,   31,   78,    1,   31,   78,
       29,   31,   78,   31,   78,   24,   31,   78,   27,   31,
       78,   31,   78,   23,   24,   31,   78,   23,   24,   31,
       78,   10,   24,   31,   78,    9,   24,   31,   78,   15,
       24,   31,   78,   31,   78,    2,   31,   78,   31,   78,
       31,   78,   31,   78,   31,   78,   30,   31,   78,   23,
       31,   78,   23,   31,   78,   10,   31,   78,    9,   31,
       78,   15,   31,   78,   25,   31,   78,   41,   78,   52,
       78,   78,   42,   78,   78,   50,   78,   51,   78,   50,

       78,   48,   78,   49,   78,   78,   56,   78,   55,   78,
       57,   78,   78,   61,   78,   56,   78,   61,   78,   71,
       78,   68,   78,   69,   78,   70,   78,   67,   78,   77,
       78,   78,   62,   78,   64,   78,   63,   78,   65,   78,
       66,   78,   67,   78,   72,   78,   74,   78,   78,   76,
       78,   75,   78,   76,   78,   24,    5,    4,   13,   24,
       23,   24,    6,   22,   23,   24,   23,   24,   23,   24,
       23,   24,   24,   11,   24,   12,   24,    8,   24,   14,
       24,    3,   13,   23,   18,   22,   23,   23,   23,   23,
       11,   12,    8,   19,   14,   25,   41,   52,   40,   32,

       40,   40,   33,   34,   40,   35,   36,   37,   40,   50,
       32,   48,   47,   32,   47,   47,   46,   47,   45,   47,
       43,   44,   56,   55,   57,   58,   53,   67,   77,   72,
       73,   54,   73,   76,   17,   24,    7,   20,   24,   21,
       24,   16,   24,   17,   20,   21,   16,   39,   38,   26,
       39,   38,   59,   60,   39
    } ;

static const flex_int16_t yy_accept[190] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    8,   10,   12,   15,   18,   21,   24,
       26,   29,   32,   34,   38,   42,   46,   50,   54,   56,
       59,   61,   63,   65,   67,   70,   73,   76,   79,   82,
       85,   88,   90,   92,   93,   95,   96,   98,  100,  102,
      104,  106,  107,  109,  111,  113,  114,  116,  118,  120,
      122,  124,  126,  128,  130,  132,  133,  135,  137,  139,
      141,  143,  145,  147,  149,  150,  152,  154,  156,  157,
      157,  158,  159,  161,  163,  164,  164,  167,  169,  171,

      173,  174,  176,  178,  180,  182,  183,  183,  184,  184,
      185,  186,  186,  188,  189,  190,  191,  191,  192,  193,
      194,  195,  196,  197,  198,  199,  200,  202,  203,  204,
      205,  206,  207,  208,  209,  210,  211,  212,  212,  213,
      214,  216,  217,  219,  221,  222,  223,  223,  223,  224,
      225,  226,  226,  226,  226,  227,  228,  228,  229,  230,
      231,  232,  233,  234,  235,  235,  237,  238,  240,  242,
      244,  245,  245,  246,  247,  248,  249,  250,  250,  250,
      251,  252,  253,  253,  254,  254,  255,  256,  256
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    7,    8,    1,    1,    9,   10,
       11,    1,   12,   13,   14,   15,   16,   17,   18,   18,
       18,   18,   18,   18,   18,   19,   19,   20,   20,   21,
       22,   23,    1,   24,   25,   26,   25,   25,   25,   25,
       27,   28,   29,   28,   30,   28,   31,   28,   28,   28,
       28,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       32,   33,   34,    1,   35,    1,   36,   37,   25,   25,

       25,   38,   39,   28,   40,   28,   41,   28,   42,   43,
       44,   28,   28,   45,   28,   46,   28,   47,   28,   48,
       28,   28,   49,   20,   50,   51,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[52] =
    {   0,
        1,    2,    3,    3,    1,    4,    5,    1,    6,    7,
        5,    1,    8,    1,    1,    9,   10,   10,   10,    8,
        1,    1,    1,    8,   10,   10,   11,   11,   11,   11,
       11,    8,   12,    8,   11,   10,   10,   10,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,    7,   13,
        1
    } ;

static const flex_int16_t yy_base[213] =
    {   0,
        0,  339,   51,  338,  100,  104,  108,  110,  112,  118,
      121,  136,  116,  142,  190,  238,  153,  157,  169,  178,
      361,  345,  357,  731,  352,  120,  731,  731,  731,  731,
      188,  731,  339,  274,  150,  149,  193,  162,  176,  731,
      331,  303,  195,  201,  731,  308,  204,  329,  187,  324,
        0,    0,  731,  341,  731,  354,    0,  731,  185,    0,
      731,  400,    0,  341,  731,  339,  222,  222,  731,  731,
      731,  731,  731,    0,  731,  338,  731,  731,  731,  731,
      731,  226,    0,  731,  231,    0,  731,  233,  325,  321,
      331,  731,  228,  236,  317,  240,  283,  315,  236,  121,

      434,  314,  241,  313,  309,  731,  317,  295,    0,    0,
      731,  249,  254,  731,  235,   83,    0,  731,  276,  731,
      731,  731,    0,    0,  731,  731,  731,  277,  731,  731,
      252,  731,  731,  731,    0,    0,  731,  271,    0,  731,
      731,  257,  731,  731,  731,  731,  260,    0,    0,  244,
      731,  288,  226,  218,  731,  731,  180,    0,  731,    0,
      731,  731,  172,    0,  159,  134,  731,  264,    0,  129,
      731,   82,  289,    0,  731,  268,    0,  193,  307,  731,
      278,  731,  308,  731,  310,  731,  731,  731,  472,  485,
      498,  511,  524,  537,  550,  563,  576,  578,  589,  602,

      615,  628,  641,  654,  667,  679,  692,  705,  718,  120,
      108,   95
    } ;

static const flex_int16_t yy_def[213] =
    {   0,
      188,    1,  188,    3,  189,  189,  190,  190,  191,  191,
      192,  192,  193,  193,  194,  194,  195,  195,  196,  196,
      188,  197,  188,  188,  188,  197,  188,  188,  188,  188,
      197,  188,  188,  197,   34,  197,  197,  197,  188,  188,
      188,  188,  188,  188,  188,  188,   46,  188,  188,  188,
      198,  199,  188,  188,  188,  200,  201,  188,  201,  202,
      188,  203,  204,  188,  188,  188,  188,  204,  188,  188,
      188,  188,  188,  205,  188,  188,  188,  188,  188,  188,
      188,  205,  206,  188,  207,  208,  188,  208,  197,  197,
      188,  188,  197,   34,  188,  197,   34,  197,  197,  197,

      197,  197,  197,  197,  197,  188,  188,  188,  209,   47,
      188,  188,   46,  188,  188,  188,  210,  188,  188,  188,
      188,  188,  198,  199,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  211,  201,  188,  188,  202,  188,
      188,  188,  188,  188,  188,  188,  188,  211,  204,  188,
      188,  188,  188,  188,  188,  188,  188,  205,  188,  206,
      188,  188,  188,  208,  188,  197,  188,  197,  101,  197,
      188,  209,  188,  210,  188,  188,  212,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,    0,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,

      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188
    } ;

static const flex_int16_t yy_nxt[783] =
    {   0,
       22,   23,   24,   25,   26,   27,   28,   22,   29,   30,
       30,   31,   32,   31,   33,   22,   34,   35,   35,   30,
       36,   37,   38,   30,   22,   22,   22,   22,   22,   22,
       22,   30,   39,   30,   22,   22,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   30,   30,
       22,   30,   23,   24,   25,   41,   27,   28,   42,   29,
       30,   30,   43,   30,   44,   33,   45,   46,   47,   47,
       30,   48,   49,   50,   30,   51,   51,   51,   51,   51,
       51,   51,   30,   39,   30,   30,   51,   51,   51,   51,
       51,   51,   51,   51,   51,   51,   51,   51,   51,   30,

       30,   30,   53,   54,  182,   55,   53,   54,  114,   55,
       53,   54,   53,   54,   53,   54,   58,  177,   58,  114,
       53,   54,   64,   65,   66,   71,   72,   61,   73,  174,
       67,  180,   56,   61,   90,   90,   56,   64,   65,   66,
       59,   93,   59,   90,   62,   67,   98,   71,   90,   72,
       62,   71,   72,   68,   73,   75,   76,   98,   84,   75,
       76,  162,   84,   90,   71,   72,   94,   94,   68,   69,
      102,   75,   76,   71,  162,   72,   90,   87,  106,  107,
       75,   76,  156,  105,   69,   85,   87,  137,  138,   85,
       71,   72,   75,   76,  183,   77,   78,   89,   79,   80,

       81,   88,   90,  184,   94,   94,   94,   90,  119,  120,
       88,  110,  110,  110,  103,  104,  111,  110,  110,  110,
      110,  110,   82,  152,  156,  157,  179,  153,  156,  157,
      154,  178,  155,  162,  163,  162,  165,  121,   80,   81,
       75,   76,   90,   77,   78,  150,   79,   80,   81,  166,
       90,  188,   94,   94,  188,   90,  168,  168,  168,  137,
      114,   98,  170,  116,  100,  173,  173,  173,  176,  176,
       82,  114,   98,  137,  116,  100,  176,  176,   90,  137,
      168,  168,  168,   89,  181,  181,   80,   81,   96,  152,
       97,   97,   94,  153,  187,  187,  154,  175,  155,   98,

       99,  188,  100,   99,   99,  173,  173,  173,  185,  183,
       98,  185,   99,  100,   99,   99,  171,  186,  184,  106,
      186,  101,  112,   90,  113,  113,  110,   90,   90,   90,
       89,  167,   91,  114,  115,  188,  116,  115,  115,   90,
      159,  151,  150,  125,  114,  122,  115,  116,  115,  115,
      118,  109,  108,   95,   92,  117,  127,  128,   91,   90,
      188,   40,   40,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  129,
      188,  188,  188,  188,  188,  188,  130,  131,  132,  133,

      134,  135,  141,  142,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  143,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  144,  188,  188,  129,  145,  146,  188,  188,
      188,  188,  130,  147,  132,  133,  134,  148,   90,  188,
      169,  169,  169,  188,  188,  188,  188,  188,  169,  169,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  169,
      169,  169,   52,   52,   52,   52,   52,   52,   52,   52,
       52,   52,   52,   52,   52,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   60,   60,

       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   63,   63,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   70,   70,   70,   70,   70,   70,
       70,   70,   70,   70,   70,   70,   70,   74,   74,   74,
       74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
       83,   83,   83,   83,   83,   83,   83,   83,   83,   83,
       83,   83,   83,   86,   86,   86,   86,   86,   86,   86,
       86,   86,   86,   86,   86,   86,   89,  188,  188,  188,
      188,  188,  188,  188,   89,   89,   89,  123,  123,  124,
      124,  188,  188,  124,  124,  124,  124,  124,  124,  124,

      188,  124,  126,  126,  126,  126,  126,  126,  126,  126,
      126,  126,  126,  126,  126,  136,  136,  188,  136,  136,
      188,  136,  136,  136,  136,  136,  136,  136,  139,  139,
      188,  139,  139,  139,  139,  139,  188,  139,  139,  188,
      139,  140,  140,  140,  140,  140,  140,  140,  140,  140,
      140,  140,  140,  140,  149,  188,  188,  149,  149,  149,
      188,  149,  149,  149,  149,  149,  149,  158,  158,  188,
      188,  188,  188,  188,  158,  158,  158,  158,  158,  160,
      160,  188,  188,  160,  160,  160,  160,  160,  160,  160,
      188,  160,  161,  161,  161,  161,  161,  161,  161,  161,

      161,  161,  161,  161,  161,  164,  164,  188,  164,  164,
      188,  164,  164,  164,  164,  164,  164,  164,  172,  172,
      172,  172,  172,  172,  172,  172,  172,  172,  172,  172,
       21,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188
    } ;

static const flex_int16_t yy_chk[783] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,

        3,    3,    5,    5,  212,    5,    6,    6,  116,    6,
        7,    7,    8,    8,    9,    9,    7,  211,    8,  116,
       10,   10,   11,   11,   11,   13,   13,    9,   13,  210,
       11,  172,    5,   10,   26,  100,    6,   12,   12,   12,
        7,   26,    8,  170,    9,   12,  100,   13,  166,   13,
       10,   14,   14,   11,   14,   17,   17,  100,   17,   18,
       18,  165,   18,   36,   13,   13,   35,   35,   12,   11,
       36,   19,   19,   14,  163,   14,   38,   19,   39,   39,
       20,   20,  157,   38,   12,   17,   20,   59,   59,   18,
       14,   14,   15,   15,  178,   15,   15,   35,   15,   15,

       15,   19,   31,  178,   31,   31,   31,   37,   49,   49,
       20,   43,   43,   43,   37,   37,   43,   44,   44,   44,
       47,   47,   15,   67,   68,   68,  154,   67,   82,   82,
       67,  153,   67,   85,   85,   88,   88,   49,   15,   15,
       16,   16,   93,   16,   16,  150,   16,   16,   16,   93,
       99,   47,   94,   94,   96,  103,   96,   96,   96,  142,
      115,   99,  103,  115,   99,  112,  112,  112,  131,  131,
       16,  115,   99,  138,  115,   99,  147,  147,  168,  128,
      168,  168,  168,   94,  176,  176,   16,   16,   34,  152,
       34,   34,   34,  152,  181,  181,  152,  119,  152,   34,

       34,  113,   34,   34,   34,  173,  173,  173,  179,  183,
       34,  185,   34,   34,   34,   34,  108,  179,  183,  107,
      185,   34,   46,  105,   46,   46,   46,  104,  102,   98,
       97,   95,   91,   46,   46,   90,   46,   46,   46,   89,
       76,   66,   64,   54,   46,   50,   46,   46,   46,   46,
       48,   42,   41,   33,   25,   46,   56,   56,   23,   22,
       21,    4,    2,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   56,
        0,    0,    0,    0,    0,    0,   56,   56,   56,   56,

       56,   56,   62,   62,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   62,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   62,    0,    0,   62,   62,   62,    0,    0,
        0,    0,   62,   62,   62,   62,   62,   62,  101,    0,
      101,  101,  101,    0,    0,    0,    0,    0,  101,  101,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  101,
      101,  101,  189,  189,  189,  189,  189,  189,  189,  189,
      189,  189,  189,  189,  189,  190,  190,  190,  190,  190,
      190,  190,  190,  190,  190,  190,  190,  190,  191,  191,

      191,  191,  191,  191,  191,  191,  191,  191,  191,  191,
      191,  192,  192,  192,  192,  192,  192,  192,  192,  192,
      192,  192,  192,  192,  193,  193,  193,  193,  193,  193,
      193,  193,  193,  193,  193,  193,  193,  194,  194,  194,
      194,  194,  194,  194,  194,  194,  194,  194,  194,  194,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  196,  196,  196,  196,  196,  196,  196,
      196,  196,  196,  196,  196,  196,  197,    0,    0,    0,
        0,    0,    0,    0,  197,  197,  197,  198,  198,  199,
      199,    0,    0,  199,  199,  199,  199,  199,  199,  199,

        0,  199,  200,  200,  200,  200,  200,  200,  200,  200,
      200,  200,  200,  200,  200,  201,  201,    0,  201,  201,
        0,  201,  201,  201,  201,  201,  201,  201,  202,  202,
        0,  202,  202,  202,  202,  202,    0,  202,  202,    0,
      202,  203,  203,  203,  203,  203,  203,  203,  203,  203,
      203,  203,  203,  203,  204,    0,    0,  204,  204,  204,
        0,  204,  204,  204,  204,  204,  204,  205,  205,    0,
        0,    0,    0,    0,  205,  205,  205,  205,  205,  206,
      206,    0,    0,  206,  206,  206,  206,  206,  206,  206,
        0,  206,  207,  207,  207,  207,  207,  207,  207,  207,

      207,  207,  207,  207,  207,  208,  208,    0,  208,  208,
        0,  208,  208,  208,  208,  208,  208,  208,  209,  209,
      209,  209,  209,  209,  209,  209,  209,  209,  209,  209,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188,  188,  188,  188,  188,  188,  188,  188,  188,
      188,  188
    } ;

#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "/source/lib/cfg-lex.l"
/*
 * Copyright (c) 2002-2013 Balabit
 * Copyright (c) 1998-2011 Balázs Scheidler
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * As an additional exemption you are allowed to compile & link against the
 * OpenSSL libraries as published by the OpenSSL project. See the file
 * COPYING for details.
 *
 */
#line 25 "/source/lib/cfg-lex.l"

#include "syslog-ng.h"
#include "cfg-lexer.h"
#include "cfg-lexer-subst.h"
#include "cfg-grammar.h"
#include "messages.h"
#include "parse-number.h"

#include <string.h>
#include <strings.h>

static gboolean
yy_input_run_backtick_substitution(CfgLexer *self, gchar *buf, gsize buf_size, gsize *len)
{
  gchar *res;
  GError *error = NULL;
  CFG_LTYPE *cur_lloc = &self->include_stack[self->include_depth].lloc;

  res = cfg_lexer_subst_args_in_input(self->cfg->globals, NULL, NULL, buf, -1, len, &error);
  if (!res)
    {
      msg_error("Error performing backtick substitution in configuration file",
                evt_tag_str("error", error->message),
                evt_tag_str("filename", cur_lloc->name),
                evt_tag_printf("line", "%d:%d", cur_lloc->first_line, cur_lloc->first_column));
      g_clear_error(&error);
      goto error;
    }
  else
    {
      if (*len > buf_size)
        {
          msg_error("Error performing backtick substitution in configuration file, the target buffer is too small",
                    evt_tag_int("buf_size", buf_size),
                    evt_tag_str("filename", cur_lloc->name),
                    evt_tag_printf("line", "%d:%d", cur_lloc->first_line, cur_lloc->first_column));
          goto error;
        }
      else
        {
          memcpy(buf, res, *len);
        }
      g_free(res);
      return TRUE;
    }
 error:
  return FALSE;
}

static gboolean
yy_patch_include_statement(CfgLexer *self, gchar *buf, gsize buf_size, gsize *len)
{
  CFG_LTYPE *cur_lloc = &self->include_stack[self->include_depth].lloc;

  gchar *p = buf;
  p += strspn(p, " \t");
  if (strncmp(p, "include", 7) != 0)
    return TRUE;
  p += 7;
  if (*p != ' ' && *p != '\t')
    return TRUE;

  p = strrchr(p, ';');
  if (!p)
    return TRUE;
  *p = ' ';

  if (!cfg_is_config_version_older(configuration, VERSION_VALUE_3_20))
    {
      msg_error("Error parsing old style include statement (e.g. the one without the '@' prefix), "
                "support for it was removed in " VERSION_3_20 ", just add a '@' in front or revert to @version "
                VERSION_3_19 " or older",
                evt_tag_str("filename", cur_lloc->name),
                evt_tag_printf("line", "%d:%d", cur_lloc->first_line, cur_lloc->first_column));

      return FALSE;
    }

  if (*len + 1 > buf_size)
    {
      msg_error("Error performing the `include' patching to @include, the target buffer is too small",
                evt_tag_int("buf_size", buf_size),
                evt_tag_str("filename", cur_lloc->name),
                evt_tag_printf("line", "%d:%d", cur_lloc->first_line, cur_lloc->first_column));
      return FALSE;
    }

  memmove(buf + 1, buf, *len);
  buf[0] = '@';
  *len += 1;

  msg_warning("WARNING: the `include' keyword based inclusion syntax (e.g. the one without a '@' "
              "character in front) has been removed in " VERSION_3_20 ". Please prepend a '@' "
              "character in front of your include statement while updating your configuration "
              "to match the new version",
              evt_tag_str("filename", cur_lloc->name),
              evt_tag_printf("line", "%d:%d", cur_lloc->first_line, cur_lloc->first_column));
  return TRUE;
}

static gint
yy_filter_input(CfgLexer *self, gchar *buf, gsize buf_size)
{
  gsize len = strlen(buf);

  if (!yy_input_run_backtick_substitution(self, buf, buf_size, &len))
    return -1;
  if (!yy_patch_include_statement(self, buf, buf_size, &len))
    return -1;
  return len;
}

#define YY_INPUT(buf, result, max_size)                                 \
  do                                                                    \
    {                                                                   \
      if (!fgets(buf, max_size, yyin))                                  \
        result = YY_NULL;                                               \
      else if (YY_START >= block)                                       \
        result = strlen(buf);                                           \
      else                                                              \
        {                                                               \
          gint rc;                                                      \
          rc = yy_filter_input(yyextra, buf, max_size); 		\
          if (rc < 0)                                                   \
            {                                                           \
              YY_FATAL_ERROR("configuration input filtering failure");  \
            }                                                           \
          else                                                          \
            {                                                           \
              result = rc;                                              \
            }                                                           \
        }                                                               \
    } while(0)

#define YY_USER_ACTION                                                  \
  do {                                                                  \
    CFG_LTYPE *cur_lloc = &yyextra->include_stack[yyextra->include_depth].lloc; \
    if (YY_START == INITIAL || YY_START == filterx) 			\
      {                                                                 \
        cur_lloc->first_column = cur_lloc->last_column;                 \
      }                                                                 \
    cur_lloc->last_column = cur_lloc->last_column + yyleng;             \
    if (yyextra->token_text)                                            \
      g_string_append_len(yyextra->token_text, yytext, yyleng);         \
    *yylloc = *cur_lloc;                                                \
  } while(0);

#define YY_BREAK \
  do {                                                                  \
    if (yyextra->token_text && (YY_START == INITIAL || YY_START == filterx)) \
      {                                                                 \
        g_string_append_len(yyextra->token_pretext, yyextra->token_text->str, yyextra->token_text->len); \
        g_string_truncate(yyextra->token_text, 0);                      \
      }                                                                 \
  } while (0);                                                          \
  break;

#define YY_FATAL_ERROR(msg)						\
  do {									\
    struct yyguts_t * __yyg = (struct yyguts_t*) yyscanner;		\
                                                                        \
    msg_error("Fatal error in configuration lexer, giving up",		\
              evt_tag_str("error", msg));							\
    longjmp(__yyg->yyextra_r->fatal_error, 1);				\
  } while(0)

#define _process_commented_line(scanner,content,cond) \
  do {                                                \
    int ch;                                           \
                                                      \
    ch = input(scanner);                              \
    while (ch != '\n' && ch != EOF && ch != 0)        \
      {                                               \
        if (cond)                                     \
          g_string_append_c(content, ch);             \
        ch = input(scanner);                          \
      }                                               \
    if (ch == '\n')                                   \
      {                                               \
        unput(ch);                                    \
      }                                               \
  } while (0)


static void
_cfg_lex_move_token_location_to_new_line(CfgLexer *lexer)
{
  CfgIncludeLevel *level = &lexer->include_stack[lexer->include_depth];

  /* if the last token span multiple lines (e.g.  block references), it
   * might happen that last_line != first_line, in that case, initialize the
   * first_line of the token to the subsequent line after last_line */

  level->lloc.first_line = level->lloc.last_line + 1;
  level->lloc.last_line = level->lloc.first_line;
  level->lloc.first_column = 1;
  level->lloc.last_column = 1;
}

static void
_cfg_lex_extend_token_location_to_next_line(CfgLexer *lexer)
{
  CfgIncludeLevel *level = &lexer->include_stack[lexer->include_depth];

  /* this function is used when encountering an NL character within a
   * multi-line string literal.
   *
   * Example:
   * |    "this is the start of the literal\
   * |    and this is the end"
   *
   *
   * In this case the string contains a escaped NL character, causing the
   * literal to span two distinct lines in the source file, which would be
   * dropped from the parsed string.
   *
   * In this case, we need to move yylloc to point from the end of the
   * current line to the beginning of the next line.  This way, by the time
   * we return the entire token, yylloc would be spanning the
   * starting-ending lines of the string literal as needed.
   * */

  level->lloc.last_line++;
  level->lloc.last_column = 1;
}

#define YYSTYPE CFG_STYPE
#define YYLTYPE CFG_LTYPE

#pragma GCC diagnostic ignored "-Wswitch-default"
#if (defined(__GNUC__) && __GNUC__ >= 6) || (defined(__clang__) && __clang_major__ >= 10)
#  pragma GCC diagnostic ignored "-Wmisleading-indentation"
#endif

#line 1190 "lib/cfg-lex.c"
/* block related states must be last, as we use this fact in YY_INPUT */

#line 1193 "lib/cfg-lex.c"

#define INITIAL 0
#define filterx 1
#define string 2
#define qstring 3
#define slash_string 4
#define block 5
#define block_arg 6
#define block_content 7
#define block_string 8
#define block_qstring 9

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE CfgLexer *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

       YYLTYPE *yyget_lloc ( yyscan_t yyscanner );
    
        void yyset_lloc ( YYLTYPE * yylloc_param , yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

    static void yy_push_state ( int _new_state , yyscan_t yyscanner);
    
    static void yy_pop_state ( yyscan_t yyscanner );
    
    static int yy_top_state ( yyscan_t yyscanner );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 288 "/source/lib/cfg-lex.l"


#line 1513 "lib/cfg-lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
		yy_current_state += YY_AT_BOL();

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 189 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 731 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];

find_rule: /* we branch to this label when backing up */

		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
					{
					yyg->yy_full_match = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
YY_RULE_SETUP
#line 290 "/source/lib/cfg-lex.l"
{
                             _process_commented_line(yyscanner,yyextra->token_text,yyextra->token_text);
                           }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 293 "/source/lib/cfg-lex.l"
{
                             return LL_PRAGMA;
                           }
	YY_BREAK
/* continuation line: just move the location and skip the newline character */
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 298 "/source/lib/cfg-lex.l"
{ _cfg_lex_extend_token_location_to_next_line(yyextra); }
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 299 "/source/lib/cfg-lex.l"
{
                             *yylloc = yyextra->include_stack[yyextra->include_depth].lloc;
                             _cfg_lex_move_token_location_to_new_line(yyextra);
                             if (yyextra->tokenize_eol)
                               return LL_EOL;
                             else
                               g_string_append(yyextra->string_buffer, yytext);
                           }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 307 "/source/lib/cfg-lex.l"
;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 308 "/source/lib/cfg-lex.l"
{ return LL_DOTDOT; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 309 "/source/lib/cfg-lex.l"
{ return LL_DOTDOTDOT; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 310 "/source/lib/cfg-lex.l"
{ return LL_ARROW; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 311 "/source/lib/cfg-lex.l"
{ return KW_ASSIGN; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 312 "/source/lib/cfg-lex.l"
{ return KW_TA_LT; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 313 "/source/lib/cfg-lex.l"
{ return KW_TA_LE; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 314 "/source/lib/cfg-lex.l"
{ return KW_TA_EQ; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 315 "/source/lib/cfg-lex.l"
{ return KW_TA_NE; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 316 "/source/lib/cfg-lex.l"
{ return KW_TA_GE; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 317 "/source/lib/cfg-lex.l"
{ return KW_TA_GT; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 318 "/source/lib/cfg-lex.l"
{ return KW_TAV_EQ; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 319 "/source/lib/cfg-lex.l"
{ return KW_TAV_NE; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 320 "/source/lib/cfg-lex.l"
{ return KW_PLUS_ASSIGN; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 321 "/source/lib/cfg-lex.l"
{ return KW_REGEXP_MATCH; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 323 "/source/lib/cfg-lex.l"
{ yylval->fnum = strtod(yytext, NULL); return LL_FLOAT; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 324 "/source/lib/cfg-lex.l"
{
                             if (!parse_int64_base16(yytext, &yylval->num))
                               {
                                 return LL_ERROR;
                               }
                             return LL_NUMBER;
                           }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 331 "/source/lib/cfg-lex.l"
{
                             if (!parse_int64_base8(yytext, &yylval->num))
                               {
                                 return LL_ERROR;
                               }
                             return LL_NUMBER;
                           }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 338 "/source/lib/cfg-lex.l"
{
                             if (!parse_int64_with_suffix(yytext, &yylval->num))
                               {
                                 return LL_ERROR;
                               }
                             return LL_NUMBER;
                           }
	YY_BREAK
/* this is the original LL_IDENTIFIER pattern, which basically allows almost everything as an unquoted string */
case 24:
YY_RULE_SETUP
#line 347 "/source/lib/cfg-lex.l"
{ return cfg_lexer_map_word_to_token(yyextra, yylval, yylloc, yytext); }
	YY_BREAK
/* and this is the version in filterx, which only allows "traditional" identifiers */
case 25:
YY_RULE_SETUP
#line 350 "/source/lib/cfg-lex.l"
{ return cfg_lexer_map_word_to_token(yyextra, yylval, yylloc, yytext); }
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 351 "/source/lib/cfg-lex.l"
{ yylval->cptr = strndup(yytext+2, strlen(yytext) - 3); return LL_MESSAGE_REF; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 352 "/source/lib/cfg-lex.l"
;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 354 "/source/lib/cfg-lex.l"
{
			     g_string_truncate(yyextra->string_buffer, 0);
			     yy_push_state(string, yyscanner);
			   }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 358 "/source/lib/cfg-lex.l"
{
			     g_string_truncate(yyextra->string_buffer, 0);
			     yy_push_state(qstring, yyscanner);
			   }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 362 "/source/lib/cfg-lex.l"
{
			     g_string_truncate(yyextra->string_buffer, 0);
			     yy_push_state(slash_string, yyscanner);
			   }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 366 "/source/lib/cfg-lex.l"
{ return (unsigned char) yytext[0]; }
	YY_BREAK
/* continuation line within a string: just move the location and skip the newline character as if it was never there */
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
#line 369 "/source/lib/cfg-lex.l"
{ _cfg_lex_extend_token_location_to_next_line(yyextra); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 370 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, 7); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 371 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, 10); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 372 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, 13); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 373 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, 9); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 374 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, 11); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 375 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, strtol(yytext+2, NULL, 16)); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 376 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, strtol(yytext+2, NULL, 8)); }
	YY_BREAK
case 40:
/* rule 40 can match eol */
YY_RULE_SETUP
#line 377 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, yytext[1]); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 378 "/source/lib/cfg-lex.l"
{ g_string_append(yyextra->string_buffer, yytext); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 379 "/source/lib/cfg-lex.l"
{
			                        yy_pop_state(yyscanner);
			                        yylval->cptr = strdup(yyextra->string_buffer->str);
			                        return LL_STRING;
		                        }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 384 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, 8); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 385 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, 12); }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 386 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, '\\'); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 387 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, '/'); }
	YY_BREAK
case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
#line 388 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, yytext[1]); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 389 "/source/lib/cfg-lex.l"
{ g_string_append(yyextra->string_buffer, yytext); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 390 "/source/lib/cfg-lex.l"
{
			                        yy_pop_state(yyscanner);
			                        yylval->cptr = strdup(yyextra->string_buffer->str);
			                        return LL_STRING;
			                }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 395 "/source/lib/cfg-lex.l"
{ g_string_append(yyextra->string_buffer, yytext); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 396 "/source/lib/cfg-lex.l"
{
			     yy_pop_state(yyscanner);
			     yylval->cptr = strdup(yyextra->string_buffer->str);
			     return LL_STRING;
			   }
	YY_BREAK
case YY_STATE_EOF(string):
case YY_STATE_EOF(qstring):
case YY_STATE_EOF(slash_string):
#line 401 "/source/lib/cfg-lex.l"
{
                             yy_pop_state(yyscanner); YY_FATAL_ERROR( "Unterminated quote" );
                           }
	YY_BREAK
/* the rule below will only be applied to embedded newlines within
     * string/qstring.  There's a difference how we handle backslash quotation
     * of newline though.
     *
     * If a \\\n sequence is in a <string> (e.g. quoted newline)
     *   - the backslash is explicitly not allowed in the greedy rule that eats string characters
     *   - thus <*>\\\r?\n rule gets applied, at the top of the file, removing the newline
     *   - location tracking is preserved
     *
     * If a \n sequence is in a <string> (e.g. embedded newline)
     *   - the newline character is processed by the rule below, thus it is
     *     included as a literal newline
     *
     * If a \\\n sequence is in a <qstring> (e.g. quotation is not supported)
     *   - the backslash is eaten by the greedy rule for qstring
     *   - <*>\\\r?\n is not matching as the backslash is not there
     *   - the rule below gets matched and the newline is included in the string
     *
     * If a \n sequence is in a <qstring> (e.g. embedded newline)
     *   - the rule below gets matched and the newline is included in the string
     */
case 52:
/* rule 52 can match eol */
YY_RULE_SETUP
#line 427 "/source/lib/cfg-lex.l"
{
                             g_string_append(yyextra->string_buffer, yytext);
                             _cfg_lex_extend_token_location_to_next_line(yyextra);
                           }
	YY_BREAK
/* continuation line within blocks: in the block header we just ignore
     * the continuation line, whereas in string/qstring we retain them
     * literally.  */
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 436 "/source/lib/cfg-lex.l"
{ _cfg_lex_extend_token_location_to_next_line(yyextra); }
	YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
#line 437 "/source/lib/cfg-lex.l"
{ g_string_append(yyextra->string_buffer, yytext); _cfg_lex_extend_token_location_to_next_line(yyextra); }
	YY_BREAK
/* rules to parse a block as a LL_BLOCK token */
case 55:
YY_RULE_SETUP
#line 440 "/source/lib/cfg-lex.l"
;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 441 "/source/lib/cfg-lex.l"
{ yy_pop_state(yyscanner); YY_FATAL_ERROR("Expected opening bracket as block boundary, e.g. opening brace or parenthesis"); }
	YY_BREAK
case 57:
/* rule 57 can match eol */
YY_RULE_SETUP
#line 442 "/source/lib/cfg-lex.l"
{ _cfg_lex_move_token_location_to_new_line(yyextra); };
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 443 "/source/lib/cfg-lex.l"
{ yy_pop_state(yyscanner); yylval->cptr = NULL; return LL_BLOCK; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 444 "/source/lib/cfg-lex.l"
{ yy_pop_state(yyscanner); yylval->cptr = g_strdup(""); return LL_BLOCK; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 445 "/source/lib/cfg-lex.l"
{ yy_pop_state(yyscanner); yylval->cptr = g_strdup(""); return LL_BLOCK; }
	YY_BREAK
/* start character of the block */
case 61:
YY_RULE_SETUP
#line 448 "/source/lib/cfg-lex.l"
{
                             if (yytext[0] != yyextra->block_boundary[0])
                               REJECT;
                             g_string_truncate(yyextra->string_buffer, 0);
                             yyextra->brace_count = 1;
                             yy_push_state(block_content, yyscanner);
                           }
	YY_BREAK
/* block_content, handle embedded string/qstring/comments properly, count
     * braces so we only end the block if they are pairing up, unless they are
     * in a string/qstring/comment. */
case 62:
YY_RULE_SETUP
#line 460 "/source/lib/cfg-lex.l"
{
                             g_string_append_c(yyextra->string_buffer, yytext[0]);
                             yy_push_state(block_string, yyscanner);
                           }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 465 "/source/lib/cfg-lex.l"
{
                             g_string_append_c(yyextra->string_buffer, yytext[0]);
                             yy_push_state(block_qstring, yyscanner);
                           }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 470 "/source/lib/cfg-lex.l"
{
                             g_string_append_c(yyextra->string_buffer, yytext[0]);
                             _process_commented_line(yyscanner, yyextra->string_buffer, TRUE);
                           }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 475 "/source/lib/cfg-lex.l"
{
                             g_string_append_c(yyextra->string_buffer, yytext[0]);
                             if (yytext[0] == yyextra->block_boundary[0])
                               yyextra->brace_count++;
                           }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 480 "/source/lib/cfg-lex.l"
{
                             if (yytext[0] == yyextra->block_boundary[1])
                               yyextra->brace_count--;
                             if (yyextra->brace_count == 0)
                               {
                                 yy_pop_state(yyscanner);
                                 yy_pop_state(yyscanner);
                                 yylval->cptr = strdup(yyextra->string_buffer->str);
                                 return LL_BLOCK;
                               }
                             else
                               {
                                 g_string_append_c(yyextra->string_buffer, yytext[0]);
                               }

                           }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 497 "/source/lib/cfg-lex.l"
{
                             g_string_append(yyextra->string_buffer, yytext);
                           }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 501 "/source/lib/cfg-lex.l"
{
                             g_string_append_c(yyextra->string_buffer, yytext[0]);
                             yyextra->brace_count++;
                           }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 505 "/source/lib/cfg-lex.l"
{
                             if (yyextra->brace_count > 0)
                               {
                                 g_string_append_c(yyextra->string_buffer, yytext[0]);
                                 yyextra->brace_count--;
                               }
                             else
                               {
                                 yy_pop_state(yyscanner);
                                 yylval->cptr = strdup(yyextra->string_buffer->str);
                                 unput(')');
                                 return LL_BLOCK;
                               }
                           }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 521 "/source/lib/cfg-lex.l"
{
                             if (yyextra->brace_count > 0)
                               {
                                 g_string_append_c(yyextra->string_buffer, yytext[0]);
                               }
                             else
                               {
                                 yy_pop_state(yyscanner);
                                 yylval->cptr = strdup(yyextra->string_buffer->str);
                                 unput(',');
                                 return LL_BLOCK;
                               }
                           }
	YY_BREAK
case 71:
/* rule 71 can match eol */
YY_RULE_SETUP
#line 534 "/source/lib/cfg-lex.l"
{ g_string_append_c(yyextra->string_buffer, yytext[0]); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 537 "/source/lib/cfg-lex.l"
{ g_string_append(yyextra->string_buffer, yytext); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 538 "/source/lib/cfg-lex.l"
{ g_string_append(yyextra->string_buffer, yytext); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 539 "/source/lib/cfg-lex.l"
{
                             g_string_append_c(yyextra->string_buffer, yytext[0]);
                             yy_pop_state(yyscanner);
                           }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 544 "/source/lib/cfg-lex.l"
{
                             g_string_append_c(yyextra->string_buffer, yytext[0]);
                             yy_pop_state(yyscanner);
                           }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 548 "/source/lib/cfg-lex.l"
{
                             g_string_append(yyextra->string_buffer, yytext);
                           }
	YY_BREAK
/* The newlines embedded in block_string/block_qstring/block_content is
     * literally coped into the block token, even if there's backslash as the
     * last character.  Basically we behave just as if the entire block was a
     * qstring.
     */
case 77:
/* rule 77 can match eol */
YY_RULE_SETUP
#line 557 "/source/lib/cfg-lex.l"
{
                             g_string_append(yyextra->string_buffer, yytext);
                             _cfg_lex_extend_token_location_to_next_line(yyextra);
                           }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(filterx):
#line 562 "/source/lib/cfg-lex.l"
{
                             if (!cfg_lexer_start_next_include(yyextra))
                               {
                                 if (yyextra->include_depth == 0)
                                   {
                                     *yylloc = yyextra->include_stack[0].lloc;
                                     yyterminate();
                                   }
                                 else
                                    return LL_ERROR;
                               }
                           }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 575 "/source/lib/cfg-lex.l"
ECHO;
	YY_BREAK
#line 2168 "lib/cfg-lex.c"
			case YY_STATE_EOF(block):
			case YY_STATE_EOF(block_arg):
			case YY_STATE_EOF(block_content):
			case YY_STATE_EOF(block_string):
			case YY_STATE_EOF(block_qstring):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;
	yy_current_state += YY_AT_BOL();

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 189 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 189 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 188);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  _new_state , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( yyg->yy_start_stack_ptr >= yyg->yy_start_stack_depth )
		{
		yy_size_t new_size;

		yyg->yy_start_stack_depth += YY_START_STACK_INCR;
		new_size = (yy_size_t) yyg->yy_start_stack_depth * sizeof( int );

		if ( ! yyg->yy_start_stack )
			yyg->yy_start_stack = (int *) yyalloc( new_size , yyscanner );

		else
			yyg->yy_start_stack = (int *) yyrealloc(
					(void *) yyg->yy_start_stack, new_size , yyscanner );

		if ( ! yyg->yy_start_stack )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	yyg->yy_start_stack[yyg->yy_start_stack_ptr++] = YY_START;

	BEGIN(_new_state);
}

    static void yy_pop_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( --yyg->yy_start_stack_ptr < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN(yyg->yy_start_stack[yyg->yy_start_stack_ptr]);
}

    static int yy_top_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	return yyg->yy_start_stack[yyg->yy_start_stack_ptr - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 575 "/source/lib/cfg-lex.l"



void
cfg_lexer_unput_string(CfgLexer *self, const char *str)
{
  int len = strlen(str);
  int i;

  for (i = len - 1; i >= 0; i--)
    {
      yyunput(str[i], _cfg_lexer_get_text(self->state), self->state);
      self->include_stack[self->include_depth].lloc.first_column--;
      self->include_stack[self->include_depth].lloc.last_column--;
    }
}

void
cfg_lexer_start_block_state(CfgLexer *self, const gchar block_boundary[2])
{
  memcpy(&self->block_boundary, block_boundary, sizeof(self->block_boundary));
  yy_push_state(block, self->state);
}

void
cfg_lexer_start_block_arg_state(CfgLexer *self)
{
  g_string_truncate(self->string_buffer, 0);
  self->brace_count = 0;
  yy_push_state(block_arg, self->state);
}

void
cfg_lexer_push_filterx_state(CfgLexer *self)
{
  yy_push_state(filterx, self->state);
}

void
cfg_lexer_pop_filterx_state(CfgLexer *self)
{
  struct yyguts_t *yyg = self->state;
  g_assert(YY_START == filterx);
  yy_pop_state(self->state);
}

/* avoid warnings of unused symbols */
gpointer __dummy[] = { yy_top_state, yy_fatal_error };

